@@ -80,7 +80,7 @@ static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCode
 		stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
 		while (gee_iterator_next (stmt_it)) {
 			ValaCCodeStatement* stmt;
-			stmt = gee_iterator_get (stmt_it);
+			stmt = ((ValaCCodeStatement*) gee_iterator_get (stmt_it));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
 				(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
