@@ -50,7 +50,10 @@ ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, Val
 	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
+	__params_it->name = "condition";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, cond);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_DO_STATEMENT, __params_it - __params, __params);
 	vala_ccode_do_statement_set_body (self, stmt);
 	while (__params_it > __params) {
