@@ -1,11 +1,11 @@
 /* valaccodedostatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEDOSTATEMENT_H__
-#define __VALACCODEDOSTATEMENT_H__
+#ifndef __CCODE_VALACCODEDOSTATEMENT_H__
+#define __CCODE_VALACCODEDOSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,11 +47,11 @@ typedef struct _ValaCCodeDoStatementPrivate ValaCCodeDoStatementPrivate;
  * Represents a do iteration statement in the C code.
  */
 struct _ValaCCodeDoStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeDoStatementPrivate * priv;
 };
 struct _ValaCCodeDoStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeDoStatement* vala_ccode_do_statement_new (ValaCCodeStatement* stmt, ValaCCodeExpression* cond);
@@ -59,7 +59,7 @@ ValaCCodeStatement* vala_ccode_do_statement_get_body (ValaCCodeDoStatement* self
 void vala_ccode_do_statement_set_body (ValaCCodeDoStatement* self, ValaCCodeStatement* value);
 ValaCCodeExpression* vala_ccode_do_statement_get_condition (ValaCCodeDoStatement* self);
 void vala_ccode_do_statement_set_condition (ValaCCodeDoStatement* self, ValaCCodeExpression* value);
-GType vala_ccode_do_statement_get_type ();
+GType vala_ccode_do_statement_get_type (void);
 
 G_END_DECLS
 
