@@ -1,6 +1,6 @@
 /* valaccodeexpressionstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,8 @@
 #include <ccode/valaccodeexpressionstatement.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ccode/valaccodecommaexpression.h>
+#include <ccode/valaccodeparenthesizedexpression.h>
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
@@ -35,6 +37,7 @@ enum  {
 	VALA_CCODE_EXPRESSION_STATEMENT_EXPRESSION
 };
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_expression_statement_write_expression (ValaCCodeExpressionStatement* self, ValaCCodeWriter* writer, ValaCCodeExpression* expr);
 static gpointer vala_ccode_expression_statement_parent_class = NULL;
 static void vala_ccode_expression_statement_dispose (GObject * obj);
 
@@ -46,7 +49,10 @@ ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpr
 	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, expr), __params_it++);
+	__params_it->name = "expression";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, expr);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_EXPRESSION_STATEMENT, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -61,9 +67,56 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (base);
 	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	if (VALA_IS_CCODE_COMMA_EXPRESSION (vala_ccode_expression_statement_get_expression (self))) {
+		ValaCCodeCommaExpression* _tmp1;
+		ValaCCodeExpression* _tmp0;
+		ValaCCodeCommaExpression* ccomma;
+		/* expand comma expression into multiple statements
+		 to improve code readability*/
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		ccomma = (_tmp1 = (_tmp0 = vala_ccode_expression_statement_get_expression (self), (VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0) ? ((ValaCCodeCommaExpression*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		{
+			GeeCollection* expr_collection;
+			GeeIterator* expr_it;
+			expr_collection = vala_ccode_comma_expression_get_inner (ccomma);
+			expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
+			while (gee_iterator_next (expr_it)) {
+				ValaCCodeExpression* expr;
+				expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
+				{
+					vala_ccode_expression_statement_write_expression (self, writer, expr);
+					(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
+				}
+			}
+			(expr_collection == NULL ? NULL : (expr_collection = (g_object_unref (expr_collection), NULL)));
+			(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
+		}
+		(ccomma == NULL ? NULL : (ccomma = (g_object_unref (ccomma), NULL)));
+	} else {
+		if (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (vala_ccode_expression_statement_get_expression (self))) {
+			ValaCCodeParenthesizedExpression* _tmp3;
+			ValaCCodeExpression* _tmp2;
+			ValaCCodeParenthesizedExpression* cpar;
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			cpar = (_tmp3 = (_tmp2 = vala_ccode_expression_statement_get_expression (self), (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp2) ? ((ValaCCodeParenthesizedExpression*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_parenthesized_expression_get_inner (cpar));
+			(cpar == NULL ? NULL : (cpar = (g_object_unref (cpar), NULL)));
+		} else {
+			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_expression_statement_get_expression (self));
+		}
+	}
+}
+
+
+static void vala_ccode_expression_statement_write_expression (ValaCCodeExpressionStatement* self, ValaCCodeWriter* writer, ValaCCodeExpression* expr) {
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION_STATEMENT (self));
+	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
-	if (vala_ccode_expression_statement_get_expression (self) != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_expression_statement_get_expression (self)), writer);
+	if (expr != NULL) {
+		vala_ccode_node_write (VALA_CCODE_NODE (expr), writer);
 	}
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
