@@ -41,7 +41,10 @@ ValaCCodeIdentifier* vala_ccode_identifier_new (const char* _name) {
 	ValaCCodeIdentifier * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
+	__params_it->name = "name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _name);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_IDENTIFIER, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -123,7 +126,7 @@ static void vala_ccode_identifier_init (ValaCCodeIdentifier * self) {
 static void vala_ccode_identifier_dispose (GObject * obj) {
 	ValaCCodeIdentifier * self;
 	self = VALA_CCODE_IDENTIFIER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	G_OBJECT_CLASS (vala_ccode_identifier_parent_class)->dispose (obj);
 }
 
