@@ -1,11 +1,11 @@
 /* valaccodeifstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEIFSTATEMENT_H__
-#define __VALACCODEIFSTATEMENT_H__
-typedef struct _ValaCCodeIfStatement ValaCCodeIfStatement;
-typedef struct _ValaCCodeIfStatementClass ValaCCodeIfStatementClass;
-typedef struct _ValaCCodeIfStatementPrivate ValaCCodeIfStatementPrivate;
+#ifndef __CCODE_VALACCODEIFSTATEMENT_H__
+#define __CCODE_VALACCODEIFSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -42,16 +39,19 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_IF_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_IF_STATEMENT))
 #define VALA_CCODE_IF_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_IF_STATEMENT, ValaCCodeIfStatementClass))
 
+typedef struct _ValaCCodeIfStatement ValaCCodeIfStatement;
+typedef struct _ValaCCodeIfStatementClass ValaCCodeIfStatementClass;
+typedef struct _ValaCCodeIfStatementPrivate ValaCCodeIfStatementPrivate;
 
 /**
  * Represents an if selection statement in the C code.
  */
 struct _ValaCCodeIfStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeIfStatementPrivate * priv;
 };
 struct _ValaCCodeIfStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt);
@@ -63,7 +63,7 @@ ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStat
 void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value);
 gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self);
 void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value);
-GType vala_ccode_if_statement_get_type ();
+GType vala_ccode_if_statement_get_type (void);
 
 G_END_DECLS
 
