@@ -44,7 +44,10 @@ ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gi
 	ValaCCodeLineDirective * self;
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
+	__params_it->name = "filename";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _filename);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_LINE_DIRECTIVE, __params_it - __params, __params);
 	vala_ccode_line_directive_set_line (self, _line);
 	while (__params_it > __params) {
@@ -66,7 +69,7 @@ static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCode
 	}
 	_tmp0 = NULL;
 	vala_ccode_writer_write_string (writer, (_tmp0 = g_strdup_printf ("#line %d \"%s\"", vala_ccode_line_directive_get_line (self), vala_ccode_line_directive_get_filename (self))));
-	(_tmp0 = (g_free (_tmp0), NULL));
+	_tmp0 = (g_free (_tmp0), NULL);
 	vala_ccode_writer_write_newline (writer);
 }
 
@@ -153,7 +156,7 @@ static void vala_ccode_line_directive_init (ValaCCodeLineDirective * self) {
 static void vala_ccode_line_directive_dispose (GObject * obj) {
 	ValaCCodeLineDirective * self;
 	self = VALA_CCODE_LINE_DIRECTIVE (obj);
-	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
+	self->priv->_filename = (g_free (self->priv->_filename), NULL);
 	G_OBJECT_CLASS (vala_ccode_line_directive_parent_class)->dispose (obj);
 }
 
