@@ -1,6 +1,6 @@
 /* valaccodemacroreplacement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
+#include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodewriter.h>
 
 G_BEGIN_DECLS
@@ -48,18 +49,21 @@ typedef struct _ValaCCodeMacroReplacementPrivate ValaCCodeMacroReplacementPrivat
  * Represents a preprocessor macro replacement definition in the C code.
  */
 struct _ValaCCodeMacroReplacement {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeMacroReplacementPrivate * priv;
 };
 struct _ValaCCodeMacroReplacementClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
-ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, const char* replace);
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement);
+ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (const char* name, ValaCCodeExpression* replacement_expression);
 char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self);
 void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, const char* value);
 char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self);
 void vala_ccode_macro_replacement_set_replacement (ValaCCodeMacroReplacement* self, const char* value);
+ValaCCodeExpression* vala_ccode_macro_replacement_get_replacement_expression (ValaCCodeMacroReplacement* self);
+void vala_ccode_macro_replacement_set_replacement_expression (ValaCCodeMacroReplacement* self, ValaCCodeExpression* value);
 GType vala_ccode_macro_replacement_get_type (void);
 
 G_END_DECLS
