@@ -94,7 +94,7 @@ static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 		decl_it = gee_iterable_iterator (GEE_ITERABLE (decl_collection));
 		while (gee_iterator_next (decl_it)) {
 			ValaCCodeDeclaration* decl;
-			decl = gee_iterator_get (decl_it);
+			decl = ((ValaCCodeDeclaration*) gee_iterator_get (decl_it));
 			{
 				vala_ccode_node_write_declaration (VALA_CCODE_NODE (decl), writer);
 				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
@@ -172,7 +172,7 @@ static void vala_ccode_struct_init (ValaCCodeStruct * self) {
 static void vala_ccode_struct_dispose (GObject * obj) {
 	ValaCCodeStruct * self;
 	self = VALA_CCODE_STRUCT (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->declarations == NULL ? NULL : (self->priv->declarations = (g_object_unref (self->priv->declarations), NULL)));
 	G_OBJECT_CLASS (vala_ccode_struct_parent_class)->dispose (obj);
 }
