@@ -93,7 +93,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 		case_stmt_it = gee_iterable_iterator (GEE_ITERABLE (case_stmt_collection));
 		while (gee_iterator_next (case_stmt_it)) {
 			ValaCCodeCaseStatement* case_stmt;
-			case_stmt = gee_iterator_get (case_stmt_it);
+			case_stmt = ((ValaCCodeCaseStatement*) gee_iterator_get (case_stmt_it));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (case_stmt), writer);
 				(case_stmt == NULL ? NULL : (case_stmt = (g_object_unref (case_stmt), NULL)));
@@ -112,7 +112,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 			stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
 			while (gee_iterator_next (stmt_it)) {
 				ValaCCodeStatement* stmt;
-				stmt = gee_iterator_get (stmt_it);
+				stmt = ((ValaCCodeStatement*) gee_iterator_get (stmt_it));
 				{
 					vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
 					(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
