@@ -1,11 +1,12 @@
 /* valacompiler.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 1996-2002, 2004, 2005, 2006 Free Software Foundation, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +21,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACOMPILER_H__
-#define __VALACOMPILER_H__
+#ifndef __COMPILER_VALACOMPILER_H__
+#define __COMPILER_VALACOMPILER_H__
 
 #include <glib.h>
 #include <glib-object.h>
