@@ -95,7 +95,7 @@ static ValaSymbol* vala_dbus_binding_provider_real_get_binding (ValaBindingProvi
 		gee_iterator_next (type_args_it);
 		_tmp1 = NULL;
 		_tmp2 = NULL;
-		ret_type = (_tmp2 = vala_data_type_copy ((_tmp1 = gee_iterator_get (type_args_it))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
+		ret_type = (_tmp2 = vala_data_type_copy ((_tmp1 = ((ValaDataType*) gee_iterator_get (type_args_it)))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
 		if (!vala_dbus_binding_provider_is_dbus_interface (self, ret_type)) {
 			gpointer _tmp3;
 			return (_tmp3 = NULL, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (type_args_it == NULL ? NULL : (type_args_it = (g_object_unref (type_args_it), NULL))), (ret_type == NULL ? NULL : (ret_type = (g_object_unref (ret_type), NULL))), _tmp3);
