@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <gobject/valainterfaceregisterfunction.h>
@@ -133,7 +133,7 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
 		while (gee_iterator_next (prereq_ref_it)) {
 			ValaDataType* prereq_ref;
-			prereq_ref = gee_iterator_get (prereq_ref_it);
+			prereq_ref = ((ValaDataType*) gee_iterator_get (prereq_ref_it));
 			{
 				ValaTypesymbol* _tmp0;
 				ValaTypesymbol* prereq;
@@ -157,13 +157,13 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 				_tmp3 = NULL;
 				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))))))));
 				(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
-				(_tmp4 = (g_free (_tmp4), NULL));
-				(_tmp3 = (g_free (_tmp3), NULL));
+				_tmp4 = (g_free (_tmp4), NULL);
+				_tmp3 = (g_free (_tmp3), NULL);
 				_tmp7 = NULL;
 				_tmp6 = NULL;
 				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_type_id (prereq))))));
 				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-				(_tmp6 = (g_free (_tmp6), NULL));
+				_tmp6 = (g_free (_tmp6), NULL);
 				_tmp8 = NULL;
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((_tmp8 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (func)))));
 				(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
