@@ -53,6 +53,7 @@ static char* vala_typeregister_function_real_get_type_flags (ValaTypeRegisterFun
 static ValaCCodeFragment* vala_typeregister_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self);
 static gpointer vala_typeregister_function_parent_class = NULL;
 static void vala_typeregister_function_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -101,7 +102,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	fundamental = FALSE;
 	_tmp0 = NULL;
 	cl = (_tmp0 = vala_typeregister_function_get_type_declaration (self), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL));
-	if (cl != NULL && vala_class_get_base_class (cl) != NULL && g_utf8_collate (vala_symbol_get_name (VALA_SYMBOL (vala_class_get_base_class (cl))), "TypeInstance") == 0 && g_utf8_collate (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_class_get_base_class (cl)))), "GLib") == 0) {
+	if (cl != NULL && vala_class_get_base_class (cl) != NULL && _vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (vala_class_get_base_class (cl))), "TypeInstance") == 0 && _vala_strcmp0 (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_class_get_base_class (cl)))), "GLib") == 0) {
 		fundamental = TRUE;
 	}
 	_tmp2 = NULL;
@@ -132,8 +133,8 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp7 = NULL;
 		_tmp6 = NULL;
 		fun = (_tmp9 = vala_ccode_function_new ((_tmp8 = g_strdup_printf ("%s_get_type", (_tmp7 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp6 = vala_typeregister_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp9);
-		(_tmp8 = (g_free (_tmp8), NULL));
-		(_tmp7 = (g_free (_tmp7), NULL));
+		_tmp8 = (g_free (_tmp8), NULL);
+		_tmp7 = (g_free (_tmp7), NULL);
 		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 		/* Function will not be prototyped anyway */
 		if (vala_typeregister_function_get_accessibility (self) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
@@ -159,8 +160,8 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp11 = NULL;
 		_tmp10 = NULL;
 		fun = (_tmp13 = vala_ccode_function_new ((_tmp12 = g_strdup_printf ("%s_register_type", (_tmp11 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp10 = vala_typeregister_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp13);
-		(_tmp12 = (g_free (_tmp12), NULL));
-		(_tmp11 = (g_free (_tmp11), NULL));
+		_tmp12 = (g_free (_tmp12), NULL);
+		_tmp11 = (g_free (_tmp11), NULL);
 		(_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL)));
 		_tmp14 = NULL;
 		vala_ccode_function_add_parameter (fun, (_tmp14 = vala_ccode_formal_parameter_new ("module", "GTypeModule *")));
@@ -201,12 +202,12 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp30 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_info", VALA_CCODE_EXPRESSION ((_tmp29 = vala_ccode_constant_new ((_tmp28 = g_strdup_printf ("{ sizeof (%s), (GBaseInitFunc) %s, (GBaseFinalizeFunc) NULL, (GClassInitFunc) %s, (GClassFinalizeFunc) NULL, NULL, %s, 0, (GInstanceInitFunc) %s }", (_tmp23 = vala_typeregister_function_get_type_struct_name (self)), (_tmp24 = vala_typeregister_function_get_base_init_func_name (self)), (_tmp25 = vala_typeregister_function_get_class_init_func_name (self)), (_tmp26 = vala_typeregister_function_get_instance_struct_size (self)), (_tmp27 = vala_typeregister_function_get_instance_init_func_name (self)))))))))));
 	(_tmp30 == NULL ? NULL : (_tmp30 = (g_object_unref (_tmp30), NULL)));
 	(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
-	(_tmp28 = (g_free (_tmp28), NULL));
-	(_tmp27 = (g_free (_tmp27), NULL));
-	(_tmp26 = (g_free (_tmp26), NULL));
-	(_tmp25 = (g_free (_tmp25), NULL));
-	(_tmp24 = (g_free (_tmp24), NULL));
-	(_tmp23 = (g_free (_tmp23), NULL));
+	_tmp28 = (g_free (_tmp28), NULL);
+	_tmp27 = (g_free (_tmp27), NULL);
+	_tmp26 = (g_free (_tmp26), NULL);
+	_tmp25 = (g_free (_tmp25), NULL);
+	_tmp24 = (g_free (_tmp24), NULL);
+	_tmp23 = (g_free (_tmp23), NULL);
 	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE (ctypedecl));
 	if (fundamental) {
 		ValaCCodeDeclaration* ctypefundamentaldecl;
@@ -269,7 +270,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp43 = NULL;
 		vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp44 = vala_ccode_identifier_new ((_tmp43 = vala_typeregister_function_get_parent_type_name (self))))));
 		(_tmp44 == NULL ? NULL : (_tmp44 = (g_object_unref (_tmp44), NULL)));
-		(_tmp43 = (g_free (_tmp43), NULL));
+		_tmp43 = (g_free (_tmp43), NULL);
 	}
 	_tmp48 = NULL;
 	_tmp47 = NULL;
@@ -277,8 +278,8 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	_tmp45 = NULL;
 	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_constant_new ((_tmp47 = g_strdup_printf ("\"%s\"", (_tmp46 = vala_typesymbol_get_cname ((_tmp45 = vala_typeregister_function_get_type_declaration (self)), FALSE))))))));
 	(_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL)));
-	(_tmp47 = (g_free (_tmp47), NULL));
-	(_tmp46 = (g_free (_tmp46), NULL));
+	_tmp47 = (g_free (_tmp47), NULL);
+	_tmp46 = (g_free (_tmp46), NULL);
 	(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
 	_tmp49 = NULL;
 	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp49 = vala_ccode_identifier_new ("&g_define_type_info"))));
@@ -293,7 +294,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	_tmp51 = NULL;
 	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp52 = vala_ccode_constant_new ((_tmp51 = vala_typeregister_function_get_type_flags (self))))));
 	(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
-	(_tmp51 = (g_free (_tmp51), NULL));
+	_tmp51 = (g_free (_tmp51), NULL);
 	_tmp55 = NULL;
 	_tmp54 = NULL;
 	_tmp53 = NULL;
@@ -344,7 +345,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	vala_ccode_function_set_block (fun, type_block);
 	vala_ccode_fragment_append (self->priv->definition_fragment, VALA_CCODE_NODE (fun));
 	(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
-	(type_id_name = (g_free (type_id_name), NULL));
+	type_id_name = (g_free (type_id_name), NULL);
 	(type_block == NULL ? NULL : (type_block = (g_object_unref (type_block), NULL)));
 	(cdecl_ == NULL ? NULL : (cdecl_ = (g_object_unref (cdecl_), NULL)));
 	(fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL)));
@@ -360,9 +361,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
  * @return type to be registered
  */
 ValaTypesymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegisterFunction* self) {
-	ValaTypesymbol* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_declaration (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_declaration (self);
 }
 
 
@@ -372,9 +371,7 @@ ValaTypesymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegiste
  * @return C struct name
  */
 char* vala_typeregister_function_get_type_struct_name (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_struct_name (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_struct_name (self);
 }
 
 
@@ -384,9 +381,7 @@ char* vala_typeregister_function_get_type_struct_name (ValaTypeRegisterFunction*
  * @return C function name
  */
 char* vala_typeregister_function_get_base_init_func_name (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_base_init_func_name (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_base_init_func_name (self);
 }
 
 
@@ -396,9 +391,7 @@ char* vala_typeregister_function_get_base_init_func_name (ValaTypeRegisterFuncti
  * @return C function name
  */
 char* vala_typeregister_function_get_class_init_func_name (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_class_init_func_name (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_class_init_func_name (self);
 }
 
 
@@ -408,9 +401,7 @@ char* vala_typeregister_function_get_class_init_func_name (ValaTypeRegisterFunct
  * @return C instance struct size
  */
 char* vala_typeregister_function_get_instance_struct_size (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_struct_size (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_struct_size (self);
 }
 
 
@@ -420,9 +411,7 @@ char* vala_typeregister_function_get_instance_struct_size (ValaTypeRegisterFunct
  * @return C function name
  */
 char* vala_typeregister_function_get_instance_init_func_name (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_init_func_name (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_init_func_name (self);
 }
 
 
@@ -432,9 +421,7 @@ char* vala_typeregister_function_get_instance_init_func_name (ValaTypeRegisterFu
  * @return C parent type name
  */
 char* vala_typeregister_function_get_parent_type_name (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_parent_type_name (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_parent_type_name (self);
 }
 
 
@@ -450,9 +437,7 @@ static char* vala_typeregister_function_real_get_type_flags (ValaTypeRegisterFun
 
 
 char* vala_typeregister_function_get_type_flags (ValaTypeRegisterFunction* self) {
-	char* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_flags (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_flags (self);
 }
 
 
@@ -468,9 +453,7 @@ static ValaCCodeFragment* vala_typeregister_function_real_get_type_interface_ini
 
 
 ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_declaration (ValaTypeRegisterFunction* self) {
-	ValaCCodeFragment* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_declaration (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_declaration (self);
 }
 
 
@@ -480,9 +463,7 @@ ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_declaratio
  * @return C statements
  */
 ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_statements (ValaTypeRegisterFunction* self) {
-	ValaCCodeFragment* result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_statements (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_statements (self);
 }
 
 
@@ -516,9 +497,7 @@ ValaCCodeFragment* vala_typeregister_function_get_definition (ValaTypeRegisterFu
  * Returns the accessibility for this type.
  */
 ValaSymbolAccessibility vala_typeregister_function_get_accessibility (ValaTypeRegisterFunction* self) {
-	ValaSymbolAccessibility result;
-	result = VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_accessibility (self);
-	return result;
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_accessibility (self);
 }
 
 
@@ -557,5 +536,16 @@ GType vala_typeregister_function_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
