@@ -7,7 +7,6 @@
 #include <vala/valablock.h>
 #include <vala/valabooleanliteral.h>
 #include <vala/valabreakstatement.h>
-#include <vala/valacallback.h>
 #include <vala/valacastexpression.h>
 #include <vala/valacatchclause.h>
 #include <vala/valacharacterliteral.h>
@@ -18,18 +17,20 @@
 #include <vala/valaconstructor.h>
 #include <vala/valacontinuestatement.h>
 #include <vala/valacreationmethod.h>
+#include <vala/valadatatype.h>
 #include <vala/valadeclarationstatement.h>
+#include <vala/valadelegate.h>
 #include <vala/valadestructor.h>
 #include <vala/valadostatement.h>
 #include <vala/valaelementaccess.h>
 #include <vala/valaemptystatement.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
+#include <vala/valaerrorcode.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valaexpression.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valafield.h>
-#include <vala/valaflags.h>
-#include <vala/valaflagsvalue.h>
 #include <vala/valaforeachstatement.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valaforstatement.h>
@@ -44,6 +45,7 @@
 #include <vala/valalocalvariabledeclaration.h>
 #include <vala/valalockstatement.h>
 #include <vala/valamemberaccess.h>
+#include <vala/valamemberinitializer.h>
 #include <vala/valamethod.h>
 #include <vala/valanamedargument.h>
 #include <vala/valanamespace.h>
@@ -53,6 +55,7 @@
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valaparser.h>
 #include <vala/valapointerindirection.h>
+#include <vala/valapointertype.h>
 #include <vala/valapostfixexpression.h>
 #include <vala/valaproperty.h>
 #include <vala/valapropertyaccessor.h>
@@ -60,6 +63,7 @@
 #include <vala/valareferencetransferexpression.h>
 #include <vala/valareport.h>
 #include <vala/valareturnstatement.h>
+#include <vala/valascope.h>
 #include <vala/valasignal.h>
 #include <vala/valasizeofexpression.h>
 #include <vala/valasourcefile.h>
@@ -74,7 +78,10 @@
 #include <vala/valatypecheck.h>
 #include <vala/valatypeofexpression.h>
 #include <vala/valatypeparameter.h>
-#include <vala/valatypereference.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valaunaryexpression.h>
+#include <vala/valaunresolvedsymbol.h>
+#include <vala/valaunresolvedtype.h>
 #include <vala/valavariabledeclarator.h>
+#include <vala/valavoidtype.h>
 #include <vala/valawhilestatement.h>
