@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valaattributeprocessor.h>
@@ -34,6 +34,7 @@ static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
+static void vala_attribute_processor_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p);
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop);
 static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* d);
 static void vala_attribute_processor_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
@@ -74,7 +75,7 @@ static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base
 		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
 		while (gee_iterator_next (ns_it)) {
 			ValaNamespace* ns;
-			ns = gee_iterator_get (ns_it);
+			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ns), VALA_CODE_VISITOR (self));
 				(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
@@ -126,6 +127,7 @@ static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, V
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
 	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
 	vala_method_process_attributes (m);
+	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 }
 
 
@@ -134,6 +136,15 @@ static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
 	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
 	vala_method_process_attributes (VALA_METHOD (m));
+	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_attribute_processor_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p) {
+	ValaAttributeProcessor * self;
+	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	g_return_if_fail (p == NULL || VALA_IS_FORMAL_PARAMETER (p));
+	vala_formal_parameter_process_attributes (p);
 }
 
 
@@ -150,6 +161,7 @@ static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base,
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
 	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
 	vala_delegate_process_attributes (d);
+	vala_code_node_accept_children (VALA_CODE_NODE (d), VALA_CODE_VISITOR (self));
 }
 
 
@@ -174,6 +186,7 @@ static void vala_attribute_processor_real_visit_signal (ValaCodeVisitor* base, V
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
 	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
 	vala_signal_process_attributes (sig);
+	vala_code_node_accept_children (VALA_CODE_NODE (sig), VALA_CODE_VISITOR (self));
 }
 
 
@@ -197,6 +210,7 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_attribute_processor_real_visit_enum;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_attribute_processor_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_attribute_processor_real_visit_creation_method;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_formal_parameter = vala_attribute_processor_real_visit_formal_parameter;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_property = vala_attribute_processor_real_visit_property;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_delegate = vala_attribute_processor_real_visit_delegate;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_attribute_processor_real_visit_constant;
