@@ -1,6 +1,6 @@
 /* valabinaryexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -38,6 +38,8 @@ enum  {
 };
 static void vala_binary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_binary_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static char* vala_binary_expression_get_operator_string (ValaBinaryExpression* self);
+static char* vala_binary_expression_real_to_string (ValaCodeNode* base);
 static gboolean vala_binary_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_binary_expression_parent_class = NULL;
 static void vala_binary_expression_dispose (GObject * obj);
@@ -61,8 +63,14 @@ ValaBinaryExpression* vala_binary_expression_new (ValaBinaryOperator op, ValaExp
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _left), __params_it++);
-	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _right), __params_it++);
+	__params_it->name = "left";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, _left);
+	__params_it++;
+	__params_it->name = "right";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, _right);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_BINARY_EXPRESSION, __params_it - __params, __params);
 	vala_binary_expression_set_operator (self, op);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -99,6 +107,89 @@ static void vala_binary_expression_real_replace_expression (ValaCodeNode* base,
 }
 
 
+static char* vala_binary_expression_get_operator_string (ValaBinaryExpression* self) {
+	ValaBinaryOperator _tmp19;
+	g_return_val_if_fail (VALA_IS_BINARY_EXPRESSION (self), NULL);
+	_tmp19 = self->priv->_operator;
+	if (_tmp19 == VALA_BINARY_OPERATOR_PLUS)
+	do {
+		return g_strdup ("+");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_MINUS)
+	do {
+		return g_strdup ("-");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_MUL)
+	do {
+		return g_strdup ("*");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_DIV)
+	do {
+		return g_strdup ("/");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_MOD)
+	do {
+		return g_strdup ("%");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_SHIFT_LEFT)
+	do {
+		return g_strdup ("<<");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_SHIFT_RIGHT)
+	do {
+		return g_strdup (">>");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_LESS_THAN)
+	do {
+		return g_strdup ("<");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_GREATER_THAN)
+	do {
+		return g_strdup (">");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_LESS_THAN_OR_EQUAL)
+	do {
+		return g_strdup ("<=");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_GREATER_THAN_OR_EQUAL)
+	do {
+		return g_strdup (">=");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_EQUALITY)
+	do {
+		return g_strdup ("==");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_INEQUALITY)
+	do {
+		return g_strdup ("!+");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_BITWISE_AND)
+	do {
+		return g_strdup ("&");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_BITWISE_OR)
+	do {
+		return g_strdup ("|");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_BITWISE_XOR)
+	do {
+		return g_strdup ("^");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_AND)
+	do {
+		return g_strdup ("&&");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_OR)
+	do {
+		return g_strdup ("||");
+	} while (0); else if (_tmp19 == VALA_BINARY_OPERATOR_IN)
+	do {
+		return g_strdup ("in");
+	} while (0);
+	g_assert_not_reached ();
+}
+
+
+static char* vala_binary_expression_real_to_string (ValaCodeNode* base) {
+	ValaBinaryExpression * self;
+	char* _tmp3;
+	char* _tmp2;
+	char* _tmp1;
+	char* _tmp0;
+	char* _tmp4;
+	self = VALA_BINARY_EXPRESSION (base);
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp4 = NULL;
+	return (_tmp4 = g_strconcat ((_tmp2 = g_strconcat ((_tmp0 = vala_code_node_to_string (VALA_CODE_NODE (self->priv->_left))), (_tmp1 = vala_binary_expression_get_operator_string (self)), NULL)), (_tmp3 = vala_code_node_to_string (VALA_CODE_NODE (self->priv->_right))), NULL), (_tmp3 = (g_free (_tmp3), NULL)), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp4);
+}
+
+
 static gboolean vala_binary_expression_real_is_pure (ValaExpression* base) {
 	ValaBinaryExpression * self;
 	self = VALA_BINARY_EXPRESSION (base);
@@ -200,6 +291,7 @@ static void vala_binary_expression_class_init (ValaBinaryExpressionClass * klass
 	G_OBJECT_CLASS (klass)->dispose = vala_binary_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_binary_expression_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_binary_expression_real_replace_expression;
+	VALA_CODE_NODE_CLASS (klass)->to_string = vala_binary_expression_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_binary_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_BINARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_BINARY_EXPRESSION_LEFT, g_param_spec_object ("left", "left", "left", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
