@@ -61,8 +61,14 @@ ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataTyp
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
-	(__params_it->name = "is-silent-cast", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, is_silent_cast), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, inner);
+	__params_it++;
+	__params_it->name = "is-silent-cast";
+	g_value_init (&__params_it->value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&__params_it->value, is_silent_cast);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CAST_EXPRESSION, __params_it - __params, __params);
 	vala_cast_expression_set_type_reference (self, type_reference);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
