@@ -69,13 +69,17 @@ void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor);
 void vala_code_context_find_header_cycles (ValaCodeContext* self);
 void vala_code_context_add_define (ValaCodeContext* self, const char* define);
 gboolean vala_code_context_ignore_node (ValaCodeContext* self, ValaCodeNode* node);
+char* vala_code_context_get_package_path (ValaCodeContext* self, const char* pkg, int vapi_directories_length1, char** vapi_directories);
 ValaNamespace* vala_code_context_create_namespace (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
 ValaClass* vala_code_context_create_class (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
 ValaStruct* vala_code_context_create_struct (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
 ValaInterface* vala_code_context_create_interface (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
 ValaEnum* vala_code_context_create_enum (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
-ValaEnumValue* vala_code_context_create_enum_value (ValaCodeContext* self, const char* name);
-ValaEnumValue* vala_code_context_create_enum_value_with_value (ValaCodeContext* self, const char* name, ValaExpression* value);
+ValaEnumValue* vala_code_context_create_enum_value (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
+ValaEnumValue* vala_code_context_create_enum_value_with_value (ValaCodeContext* self, const char* name, ValaExpression* value, ValaSourceReference* source_reference);
+ValaErrorDomain* vala_code_context_create_error_domain (ValaCodeContext* self, const char* name, ValaSourceReference* source_reference);
+ValaErrorCode* vala_code_context_create_error_code (ValaCodeContext* self, const char* name);
+ValaErrorCode* vala_code_context_create_error_code_with_value (ValaCodeContext* self, const char* name, ValaExpression* value);
 ValaDelegate* vala_code_context_create_delegate (ValaCodeContext* self, const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 ValaConstant* vala_code_context_create_constant (ValaCodeContext* self, const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 ValaField* vala_code_context_create_field (ValaCodeContext* self, const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
@@ -113,6 +117,7 @@ ValaThrowStatement* vala_code_context_create_throw_statement (ValaCodeContext* s
 ValaTryStatement* vala_code_context_create_try_statement (ValaCodeContext* self, ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference);
 ValaCatchClause* vala_code_context_create_catch_clause (ValaCodeContext* self, ValaDataType* type_reference, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
 ValaLockStatement* vala_code_context_create_lock_statement (ValaCodeContext* self, ValaExpression* resource, ValaBlock* body, ValaSourceReference* source_reference);
+ValaDeleteStatement* vala_code_context_create_delete_statement (ValaCodeContext* self, ValaExpression* expression, ValaSourceReference* source_reference);
 ValaArrayCreationExpression* vala_code_context_create_array_creation_expression (ValaCodeContext* self, ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
 ValaBooleanLiteral* vala_code_context_create_boolean_literal (ValaCodeContext* self, gboolean value, ValaSourceReference* source_reference);
 ValaCharacterLiteral* vala_code_context_create_character_literal (ValaCodeContext* self, const char* value, ValaSourceReference* source_reference);
