@@ -1,6 +1,6 @@
 /* valacodenode.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,8 @@
 #include <ccode/valaccodelinedirective.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valadatatype.h>
+#include <vala/valaexpression.h>
 #include <vala/valaattribute.h>
 #include <vala/valasourcefile.h>
 
@@ -47,10 +49,12 @@ enum  {
 };
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
-static void vala_code_node_real_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
+static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
 static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -60,7 +64,7 @@ static void vala_code_node_dispose (GObject * obj);
  */
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -76,7 +80,7 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
  */
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -85,15 +89,27 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 }
 
 
-static void vala_code_node_real_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
+	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
 }
 
 
-void vala_code_node_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCodeNode* new_node) {
-	VALA_CODE_NODE_GET_CLASS (self)->replace (self, old_node, new_node);
+void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type) {
+	VALA_CODE_NODE_GET_CLASS (self)->replace_type (self, old_type, new_type);
+}
+
+
+static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node) {
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+}
+
+
+void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node) {
+	VALA_CODE_NODE_GET_CLASS (self)->replace_expression (self, old_node, new_node);
 }
 
 
@@ -105,7 +121,6 @@ void vala_code_node_replace (ValaCodeNode* self, ValaCodeNode* old_node, ValaCod
  */
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	g_return_val_if_fail (name != NULL, NULL);
 	{
 		GList* a_collection;
 		GList* a_it;
@@ -114,10 +129,10 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
 			_tmp1 = NULL;
-			a = (_tmp1 = a_it->data, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			a = (_tmp1 = ((ValaAttribute*) a_it->data), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			{
 				/* FIXME: use hash table*/
-				if (g_utf8_collate (vala_attribute_get_name (a), name) == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
 					return a;
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -144,12 +159,11 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 		char* _tmp0;
 		_tmp0 = NULL;
 		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (vala_code_node_get_source_reference (self))));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp1 = NULL;
 	_tmp2 = NULL;
 	return (_tmp2 = (_tmp1 = g_string_append (str, " */")->str, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), _tmp2);
-	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 }
 
 
@@ -193,24 +207,21 @@ ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
 
 
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
-	ValaCCodeNode* _tmp5;
 	ValaCCodeNode* _tmp4;
+	ValaCCodeNode* _tmp3;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
 	if (vala_code_node_get_source_reference (self) != NULL) {
-		ValaCCodeLineDirective* _tmp3;
-		char* _tmp2;
+		ValaCCodeLineDirective* _tmp2;
 		char* _tmp1;
-		_tmp3 = NULL;
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		vala_ccode_node_set_line (value, (_tmp3 = vala_ccode_line_directive_new ((_tmp2 = g_build_filename ((_tmp1 = g_get_current_dir ()), vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))), NULL)), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
-		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
-		(_tmp2 = (g_free (_tmp2), NULL));
-		(_tmp1 = (g_free (_tmp1), NULL));
+		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+		_tmp1 = (g_free (_tmp1), NULL);
 	}
-	_tmp5 = NULL;
 	_tmp4 = NULL;
-	self->priv->_ccodenode = (_tmp5 = (_tmp4 = value, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), _tmp5);
+	_tmp3 = NULL;
+	self->priv->_ccodenode = (_tmp4 = (_tmp3 = value, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL))), _tmp4);
 }
 
 
@@ -320,7 +331,8 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_code_node_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_code_node_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_code_node_real_accept_children;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_code_node_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_code_node_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_code_node_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", VALA_TYPE_CODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "source-reference", "source-reference", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -357,5 +369,16 @@ GType vala_code_node_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
