@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valacodevisitor.h>
@@ -29,6 +29,8 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valaerrorcode.h>
 #include <vala/valadelegate.h>
 #include <vala/valamember.h>
 #include <vala/valaconstant.h>
@@ -67,6 +69,7 @@
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
 #include <vala/valalockstatement.h>
+#include <vala/valadeletestatement.h>
 #include <vala/valaarraycreationexpression.h>
 #include <vala/valabooleanliteral.h>
 #include <vala/valacharacterliteral.h>
@@ -106,6 +109,8 @@ static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStru
 static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
 static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 static void vala_code_visitor_real_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
+static void vala_code_visitor_real_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomain* edomain);
+static void vala_code_visitor_real_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* ecode);
 static void vala_code_visitor_real_visit_delegate (ValaCodeVisitor* self, ValaDelegate* d);
 static void vala_code_visitor_real_visit_member (ValaCodeVisitor* self, ValaMember* m);
 static void vala_code_visitor_real_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
@@ -144,6 +149,7 @@ static void vala_code_visitor_real_visit_throw_statement (ValaCodeVisitor* self,
 static void vala_code_visitor_real_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt);
 static void vala_code_visitor_real_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 static void vala_code_visitor_real_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
+static void vala_code_visitor_real_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt);
 static void vala_code_visitor_real_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 static void vala_code_visitor_real_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 static void vala_code_visitor_real_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
@@ -287,6 +293,38 @@ void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* e
 }
 
 
+/**
+ * Visit operation called for error domains.
+ *
+ * @param edomain an error domain
+ */
+static void vala_code_visitor_real_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomain* edomain) {
+	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
+	g_return_if_fail (edomain == NULL || VALA_IS_ERROR_DOMAIN (edomain));
+}
+
+
+void vala_code_visitor_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomain* edomain) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_error_domain (self, edomain);
+}
+
+
+/**
+ * Visit operation called for error codes.
+ *
+ * @param ecode an error code
+ */
+static void vala_code_visitor_real_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* ecode) {
+	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
+	g_return_if_fail (ecode == NULL || VALA_IS_ERROR_CODE (ecode));
+}
+
+
+void vala_code_visitor_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* ecode) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_error_code (self, ecode);
+}
+
+
 /**
  * Visit operation called for delegates.
  *
@@ -895,6 +933,22 @@ void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStat
 }
 
 
+/**
+ * Visit operation called for delete statements.
+ *
+ * @param stmt a delete statement
+ */
+static void vala_code_visitor_real_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt) {
+	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
+	g_return_if_fail (stmt == NULL || VALA_IS_DELETE_STATEMENT (stmt));
+}
+
+
+void vala_code_visitor_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_delete_statement (self, stmt);
+}
+
+
 /**
  * Visit operations called for array creation expresions.
  *
@@ -1352,6 +1406,8 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_code_visitor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_code_visitor_real_visit_enum;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_code_visitor_real_visit_enum_value;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_code_visitor_real_visit_error_domain;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_code = vala_code_visitor_real_visit_error_code;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_delegate = vala_code_visitor_real_visit_delegate;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member = vala_code_visitor_real_visit_member;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_code_visitor_real_visit_constant;
@@ -1390,6 +1446,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_try_statement = vala_code_visitor_real_visit_try_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_code_visitor_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_lock_statement = vala_code_visitor_real_visit_lock_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_delete_statement = vala_code_visitor_real_visit_delete_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_code_visitor_real_visit_array_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_boolean_literal = vala_code_visitor_real_visit_boolean_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_character_literal = vala_code_visitor_real_visit_character_literal;
