@@ -50,6 +50,7 @@ static gpointer vala_constant_parent_class = NULL;
 static ValaLockableIface* vala_constant_vala_lockable_parent_iface = NULL;
 static void vala_constant_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -119,8 +120,8 @@ char* vala_constant_get_cname (ValaConstant* self) {
 			_tmp3 = NULL;
 			_tmp2 = NULL;
 			self->priv->cname = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = g_utf8_strup ((_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), -1)), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp4);
-			(_tmp3 = (g_free (_tmp3), NULL));
-			(_tmp2 = (g_free (_tmp2), NULL));
+			_tmp3 = (g_free (_tmp3), NULL);
+			_tmp2 = (g_free (_tmp2), NULL);
 		}
 	}
 	_tmp5 = NULL;
@@ -177,12 +178,12 @@ static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttri
 				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
 					vala_member_add_cheader_filename (VALA_MEMBER (self), filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
-		(val = (g_free (val), NULL));
+		val = (g_free (val), NULL);
 	}
 }
 
@@ -200,9 +201,9 @@ void vala_constant_process_attributes (ValaConstant* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_constant_process_ccode_attribute (self, a);
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -310,7 +311,7 @@ static void vala_constant_dispose (GObject * obj) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (obj);
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
+	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_constant_parent_class)->dispose (obj);
 }
@@ -345,5 +346,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
