@@ -22,8 +22,8 @@
 
 #include <vala/valadelegate.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <vala/valatypeparameter.h>
@@ -38,16 +38,24 @@
 
 struct _ValaDelegatePrivate {
 	gboolean _instance;
+	double _cinstance_parameter_position;
+	double _carray_length_parameter_position;
+	double _cdelegate_target_parameter_position;
 	GeeList* type_parameters;
 	GeeList* parameters;
 	char* cname;
 	ValaDataType* _return_type;
+	gboolean _no_array_length;
 };
 #define VALA_DELEGATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DELEGATE, ValaDelegatePrivate))
 enum  {
 	VALA_DELEGATE_DUMMY_PROPERTY,
 	VALA_DELEGATE_RETURN_TYPE,
-	VALA_DELEGATE_INSTANCE
+	VALA_DELEGATE_INSTANCE,
+	VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION,
+	VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION,
+	VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION,
+	VALA_DELEGATE_NO_ARRAY_LENGTH
 };
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -59,8 +67,11 @@ static char* vala_delegate_real_get_marshaller_type_name (ValaTypesymbol* base);
 static char* vala_delegate_real_get_get_value_function (ValaTypesymbol* base);
 static char* vala_delegate_real_get_set_value_function (ValaTypesymbol* base);
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_delegate_parent_class = NULL;
 static void vala_delegate_dispose (GObject * obj);
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -105,6 +116,13 @@ void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p)
 void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
 	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	if (vala_delegate_get_no_array_length (self)) {
+		vala_formal_parameter_set_no_array_length (param, TRUE);
+	}
+	/* default C parameter position*/
+	vala_formal_parameter_set_cparameter_position (param, ((double) gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1));
+	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
+	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
 }
@@ -115,9 +133,9 @@ void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param
  *
  * @return parameter list
  */
-GeeCollection* vala_delegate_get_parameters (ValaDelegate* self) {
+GeeList* vala_delegate_get_parameters (ValaDelegate* self) {
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->parameters)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->parameters));
 }
 
 
@@ -148,7 +166,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
 			{
 				ValaFormalParameter* method_param;
 				/* use first callback parameter as instance parameter if
@@ -165,7 +183,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 					break;
 				}
-				method_param = gee_iterator_get (method_params_it);
+				method_param = ((ValaFormalParameter*) gee_iterator_get (method_params_it));
 				if (!vala_data_type_stricter (vala_formal_parameter_get_type_reference (param), vala_formal_parameter_get_type_reference (method_param))) {
 					gboolean _tmp1;
 					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp1);
@@ -204,7 +222,7 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 		p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
 		while (gee_iterator_next (p_it)) {
 			ValaTypeParameter* p;
-			p = gee_iterator_get (p_it);
+			p = ((ValaTypeParameter*) gee_iterator_get (p_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
 				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
@@ -220,7 +238,7 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
@@ -241,7 +259,7 @@ static char* vala_delegate_real_get_cname (ValaTypesymbol* base, gboolean const_
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
 	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
@@ -270,7 +288,39 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
 		char* _tmp0;
 		_tmp0 = NULL;
 		vala_delegate_set_cname (self, (_tmp0 = vala_attribute_get_string (a, "cname")));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
+	}
+	if (vala_attribute_has_argument (a, "instance_pos")) {
+		vala_delegate_set_cinstance_parameter_position (self, vala_attribute_get_double (a, "instance_pos"));
+	}
+	if (vala_attribute_has_argument (a, "array_length_pos")) {
+		vala_delegate_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
+	}
+	if (vala_attribute_has_argument (a, "delegate_target_pos")) {
+		vala_delegate_set_cdelegate_target_parameter_position (self, vala_attribute_get_double (a, "delegate_target_pos"));
+	}
+	if (vala_attribute_has_argument (a, "cheader_filename")) {
+		char* val;
+		val = vala_attribute_get_string (a, "cheader_filename");
+		{
+			char** filename_collection;
+			char** filename_it;
+			int filename_collection_length1;
+			filename_collection = g_strsplit (val, ",", 0);
+			filename_collection_length1 = -1;
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* _tmp1;
+				char* filename;
+				_tmp1 = NULL;
+				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+				{
+					vala_typesymbol_add_cheader_filename (VALA_TYPESYMBOL (self), filename);
+					filename = (g_free (filename), NULL);
+				}
+			}
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+		}
+		val = (g_free (val), NULL);
 	}
 }
 
@@ -288,10 +338,14 @@ void vala_delegate_process_attributes (ValaDelegate* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_delegate_process_ccode_attribute (self, a);
+				} else {
+					if (_vala_strcmp0 (vala_attribute_get_name (a), "NoArrayLength") == 0) {
+						vala_delegate_set_no_array_length (self, TRUE);
+					}
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
@@ -375,6 +429,87 @@ void vala_delegate_set_instance (ValaDelegate* self, gboolean value) {
 }
 
 
+double vala_delegate_get_cinstance_parameter_position (ValaDelegate* self) {
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	return self->priv->_cinstance_parameter_position;
+}
+
+
+void vala_delegate_set_cinstance_parameter_position (ValaDelegate* self, double value) {
+	g_return_if_fail (VALA_IS_DELEGATE (self));
+	self->priv->_cinstance_parameter_position = value;
+}
+
+
+double vala_delegate_get_carray_length_parameter_position (ValaDelegate* self) {
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	return self->priv->_carray_length_parameter_position;
+}
+
+
+void vala_delegate_set_carray_length_parameter_position (ValaDelegate* self, double value) {
+	g_return_if_fail (VALA_IS_DELEGATE (self));
+	self->priv->_carray_length_parameter_position = value;
+}
+
+
+double vala_delegate_get_cdelegate_target_parameter_position (ValaDelegate* self) {
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), 0.0);
+	return self->priv->_cdelegate_target_parameter_position;
+}
+
+
+void vala_delegate_set_cdelegate_target_parameter_position (ValaDelegate* self, double value) {
+	g_return_if_fail (VALA_IS_DELEGATE (self));
+	self->priv->_cdelegate_target_parameter_position = value;
+}
+
+
+gboolean vala_delegate_get_no_array_length (ValaDelegate* self) {
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
+	return self->priv->_no_array_length;
+}
+
+
+void vala_delegate_set_no_array_length (ValaDelegate* self, gboolean value) {
+	g_return_if_fail (VALA_IS_DELEGATE (self));
+	self->priv->_no_array_length = value;
+	{
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			{
+				vala_formal_parameter_set_no_array_length (param, value);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+			}
+		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
+	}
+}
+
+
+static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
+	GObject * obj;
+	ValaDelegateClass * klass;
+	GObjectClass * parent_class;
+	ValaDelegate * self;
+	klass = VALA_DELEGATE_CLASS (g_type_class_peek (VALA_TYPE_DELEGATE));
+	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
+	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
+	self = VALA_DELEGATE (obj);
+	{
+		vala_delegate_set_cinstance_parameter_position (self, ((double) -1));
+		vala_delegate_set_carray_length_parameter_position (self, ((double) -3));
+		vala_delegate_set_cdelegate_target_parameter_position (self, ((double) -3));
+	}
+	return obj;
+}
+
+
 static void vala_delegate_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (object);
@@ -385,6 +520,18 @@ static void vala_delegate_get_property (GObject * object, guint property_id, GVa
 		case VALA_DELEGATE_INSTANCE:
 		g_value_set_boolean (value, vala_delegate_get_instance (self));
 		break;
+		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
+		g_value_set_double (value, vala_delegate_get_cinstance_parameter_position (self));
+		break;
+		case VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION:
+		g_value_set_double (value, vala_delegate_get_carray_length_parameter_position (self));
+		break;
+		case VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION:
+		g_value_set_double (value, vala_delegate_get_cdelegate_target_parameter_position (self));
+		break;
+		case VALA_DELEGATE_NO_ARRAY_LENGTH:
+		g_value_set_boolean (value, vala_delegate_get_no_array_length (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -402,6 +549,18 @@ static void vala_delegate_set_property (GObject * object, guint property_id, con
 		case VALA_DELEGATE_INSTANCE:
 		vala_delegate_set_instance (self, g_value_get_boolean (value));
 		break;
+		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
+		vala_delegate_set_cinstance_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION:
+		vala_delegate_set_carray_length_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION:
+		vala_delegate_set_cdelegate_target_parameter_position (self, g_value_get_double (value));
+		break;
+		case VALA_DELEGATE_NO_ARRAY_LENGTH:
+		vala_delegate_set_no_array_length (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -414,6 +573,7 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaDelegatePrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_delegate_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_delegate_set_property;
+	G_OBJECT_CLASS (klass)->constructor = vala_delegate_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_delegate_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_delegate_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_delegate_real_accept_children;
@@ -426,6 +586,10 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_delegate_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION, g_param_spec_double ("cinstance-parameter-position", "cinstance-parameter-position", "cinstance-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -441,7 +605,7 @@ static void vala_delegate_dispose (GObject * obj) {
 	self = VALA_DELEGATE (obj);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
+	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	G_OBJECT_CLASS (vala_delegate_parent_class)->dispose (obj);
 }
@@ -457,5 +621,33 @@ GType vala_delegate_get_type (void) {
 }
 
 
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	if (array != NULL && destroy_func != NULL) {
+		int i;
+		if (array_length >= 0)
+		for (i = 0; i < array_length; i = i + 1) {
+			if (((gpointer*) array)[i] != NULL)
+			destroy_func (((gpointer*) array)[i]);
+		}
+		else
+		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) array)[i]);
+		}
+	}
+	g_free (array);
+}
+
+
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
