@@ -1,11 +1,11 @@
 /* valaemptystatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAEMPTYSTATEMENT_H__
-#define __VALAEMPTYSTATEMENT_H__
-typedef struct _ValaEmptyStatementPrivate ValaEmptyStatementPrivate;
+#ifndef __VALA_VALAEMPTYSTATEMENT_H__
+#define __VALA_VALAEMPTYSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -39,20 +38,21 @@ G_BEGIN_DECLS
 #define VALA_IS_EMPTY_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EMPTY_STATEMENT))
 #define VALA_EMPTY_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EMPTY_STATEMENT, ValaEmptyStatementClass))
 
+typedef struct _ValaEmptyStatementPrivate ValaEmptyStatementPrivate;
 
 /**
  * An empty statement.
  */
 struct _ValaEmptyStatement {
-	ValaStatement parent;
+	ValaCodeNode parent_instance;
 	ValaEmptyStatementPrivate * priv;
 };
 struct _ValaEmptyStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source);
-GType vala_empty_statement_get_type ();
+GType vala_empty_statement_get_type (void);
 
 G_END_DECLS
 
