@@ -91,14 +91,14 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
 		char* _tmp1;
 		l++;
 		_tmp1 = NULL;
-		number = (_tmp1 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), _tmp1);
+		number = (_tmp1 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp1);
 	}
 	u = FALSE;
 	if (g_str_has_suffix (number, "U")) {
 		char* _tmp2;
 		u = TRUE;
 		_tmp2 = NULL;
-		number = (_tmp2 = g_strndup (number, strlen (number) - 1), (number = (g_free (number), NULL)), _tmp2);
+		number = (_tmp2 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp2);
 	}
 	n = g_ascii_strtoll (number, NULL, 0);
 	if (!u && n > 0x7fffffff) {
@@ -143,7 +143,7 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
 			}
 		}
 	}
-	(number = (g_free (number), NULL));
+	number = (g_free (number), NULL);
 }
 
 
@@ -211,7 +211,7 @@ static void vala_integer_literal_init (ValaIntegerLiteral * self) {
 static void vala_integer_literal_dispose (GObject * obj) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (obj);
-	(self->priv->_value = (g_free (self->priv->_value), NULL));
+	self->priv->_value = (g_free (self->priv->_value), NULL);
 	G_OBJECT_CLASS (vala_integer_literal_parent_class)->dispose (obj);
 }
 
