@@ -30,6 +30,10 @@
 #include <vala/valafield.h>
 #include <vala/valaproperty.h>
 #include <vala/valasignal.h>
+#include <vala/valaclass.h>
+#include <vala/valastruct.h>
+#include <vala/valaenum.h>
+#include <vala/valadelegate.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
@@ -52,6 +56,10 @@ struct _ValaInterfacePrivate {
 	GeeList* fields;
 	GeeList* properties;
 	GeeList* signals;
+	GeeList* classes;
+	GeeList* structs;
+	GeeList* enums;
+	GeeList* delegates;
 	char* cname;
 	char* lower_case_csuffix;
 	char* type_cname;
@@ -85,6 +93,7 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 static gpointer vala_interface_parent_class = NULL;
 static void vala_interface_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -173,6 +182,8 @@ GeeCollection* vala_interface_get_prerequisites (ValaInterface* self) {
  * @param m a method
  */
 void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
+	GeeCollection* _tmp2;
+	gboolean _tmp3;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
 	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
@@ -190,15 +201,16 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
 	}
-	if (!(VALA_IS_VOID_TYPE (vala_method_get_return_type (m)))) {
-		ValaVariableDeclarator* _tmp2;
-		ValaDataType* _tmp3;
-		_tmp2 = NULL;
-		vala_method_set_result_var (m, (_tmp2 = vala_variable_declarator_new ("result", NULL, NULL)));
-		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
-		_tmp3 = NULL;
-		vala_variable_declarator_set_type_reference (vala_method_get_result_var (m), (_tmp3 = vala_data_type_copy (vala_method_get_return_type (m))));
-		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+	_tmp2 = NULL;
+	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size ((_tmp2 = vala_method_get_postconditions (m))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
+		ValaVariableDeclarator* _tmp4;
+		ValaDataType* _tmp5;
+		_tmp4 = NULL;
+		vala_method_set_result_var (m, (_tmp4 = vala_variable_declarator_new ("result", NULL, NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		_tmp5 = NULL;
+		vala_variable_declarator_set_type_reference (vala_method_get_result_var (m), (_tmp5 = vala_data_type_copy (vala_method_get_return_type (m))));
+		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
@@ -290,6 +302,58 @@ GeeCollection* vala_interface_get_signals (ValaInterface* self) {
 }
 
 
+/**
+ * Adds the specified class as an inner class.
+ *
+ * @param cl a class
+ */
+void vala_interface_add_class (ValaInterface* self, ValaClass* cl) {
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
+}
+
+
+/**
+ * Adds the specified struct as an inner struct.
+ *
+ * @param st a struct
+ */
+void vala_interface_add_struct (ValaInterface* self, ValaStruct* st) {
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	gee_collection_add (GEE_COLLECTION (self->priv->structs), st);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (st)), VALA_SYMBOL (st));
+}
+
+
+/**
+ * Adds the specified enum as an inner enum.
+ *
+ * @param en an enum
+ */
+void vala_interface_add_enum (ValaInterface* self, ValaEnum* en) {
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	gee_collection_add (GEE_COLLECTION (self->priv->enums), en);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (en)), VALA_SYMBOL (en));
+}
+
+
+/**
+ * Adds the specified delegate as an inner delegate.
+ *
+ * @param d a delegate
+ */
+void vala_interface_add_delegate (ValaInterface* self, ValaDelegate* d) {
+	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	gee_collection_add (GEE_COLLECTION (self->priv->delegates), d);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (d)), VALA_SYMBOL (d));
+}
+
+
 static char* vala_interface_real_get_cname (ValaTypesymbol* base, gboolean const_type) {
 	ValaInterface * self;
 	const char* _tmp2;
@@ -300,7 +364,7 @@ static char* vala_interface_real_get_cname (ValaTypesymbol* base, gboolean const
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		self->priv->cname = (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
 	return (_tmp2 = self->priv->cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
@@ -339,8 +403,8 @@ char* vala_interface_get_lower_case_csuffix (ValaInterface* self) {
 			_tmp5 = NULL;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			self->priv->lower_case_csuffix = (_tmp5 = g_strconcat ((_tmp4 = g_utf8_offset_to_pointer (self->priv->lower_case_csuffix, 0), g_strndup (_tmp4, g_utf8_offset_to_pointer (_tmp4, g_utf8_strlen (self->priv->lower_case_csuffix, -1) - g_utf8_strlen ("_class", -1)) - _tmp4)), "class", NULL), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp5);
-			(_tmp3 = (g_free (_tmp3), NULL));
+			self->priv->lower_case_csuffix = (_tmp5 = g_strconcat ((_tmp4 = g_utf8_offset_to_pointer (self->priv->lower_case_csuffix, ((glong) 0)), g_strndup (_tmp4, g_utf8_offset_to_pointer (_tmp4, g_utf8_strlen (self->priv->lower_case_csuffix, -1) - g_utf8_strlen ("_class", -1)) - _tmp4)), "class", NULL), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp5);
+			_tmp3 = (g_free (_tmp3), NULL);
 		}
 	}
 	_tmp6 = NULL;
@@ -421,7 +485,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
 		while (gee_iterator_next (type_it)) {
 			ValaDataType* type;
-			type = gee_iterator_get (type_it);
+			type = ((ValaDataType*) gee_iterator_get (type_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (type), visitor);
 				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
@@ -436,7 +500,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
 		while (gee_iterator_next (p_it)) {
 			ValaTypeParameter* p;
-			p = gee_iterator_get (p_it);
+			p = ((ValaTypeParameter*) gee_iterator_get (p_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
 				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
@@ -451,7 +515,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
 		while (gee_iterator_next (m_it)) {
 			ValaMethod* m;
-			m = gee_iterator_get (m_it);
+			m = ((ValaMethod*) gee_iterator_get (m_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
@@ -466,7 +530,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
 		while (gee_iterator_next (f_it)) {
 			ValaField* f;
-			f = gee_iterator_get (f_it);
+			f = ((ValaField*) gee_iterator_get (f_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
 				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
@@ -481,7 +545,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		prop_it = gee_iterable_iterator (GEE_ITERABLE (prop_collection));
 		while (gee_iterator_next (prop_it)) {
 			ValaProperty* prop;
-			prop = gee_iterator_get (prop_it);
+			prop = ((ValaProperty*) gee_iterator_get (prop_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (prop), visitor);
 				(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
@@ -496,7 +560,7 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		sig_it = gee_iterable_iterator (GEE_ITERABLE (sig_collection));
 		while (gee_iterator_next (sig_it)) {
 			ValaSignal* sig;
-			sig = gee_iterator_get (sig_it);
+			sig = ((ValaSignal*) gee_iterator_get (sig_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (sig), visitor);
 				(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
@@ -504,6 +568,66 @@ static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		}
 		(sig_it == NULL ? NULL : (sig_it = (g_object_unref (sig_it), NULL)));
 	}
+	{
+		GeeList* cl_collection;
+		GeeIterator* cl_it;
+		cl_collection = self->priv->classes;
+		cl_it = gee_iterable_iterator (GEE_ITERABLE (cl_collection));
+		while (gee_iterator_next (cl_it)) {
+			ValaClass* cl;
+			cl = ((ValaClass*) gee_iterator_get (cl_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (cl), visitor);
+				(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+			}
+		}
+		(cl_it == NULL ? NULL : (cl_it = (g_object_unref (cl_it), NULL)));
+	}
+	{
+		GeeList* st_collection;
+		GeeIterator* st_it;
+		st_collection = self->priv->structs;
+		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
+		while (gee_iterator_next (st_it)) {
+			ValaStruct* st;
+			st = ((ValaStruct*) gee_iterator_get (st_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+			}
+		}
+		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
+	}
+	{
+		GeeList* en_collection;
+		GeeIterator* en_it;
+		en_collection = self->priv->enums;
+		en_it = gee_iterable_iterator (GEE_ITERABLE (en_collection));
+		while (gee_iterator_next (en_it)) {
+			ValaEnum* en;
+			en = ((ValaEnum*) gee_iterator_get (en_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (en), visitor);
+				(en == NULL ? NULL : (en = (g_object_unref (en), NULL)));
+			}
+		}
+		(en_it == NULL ? NULL : (en_it = (g_object_unref (en_it), NULL)));
+	}
+	{
+		GeeList* d_collection;
+		GeeIterator* d_it;
+		d_collection = self->priv->delegates;
+		d_it = gee_iterable_iterator (GEE_ITERABLE (d_collection));
+		while (gee_iterator_next (d_it)) {
+			ValaDelegate* d;
+			d = ((ValaDelegate*) gee_iterator_get (d_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (d), visitor);
+				(d == NULL ? NULL : (d = (g_object_unref (d), NULL)));
+			}
+		}
+		(d_it == NULL ? NULL : (d_it = (g_object_unref (d_it), NULL)));
+	}
 }
 
 
@@ -549,7 +673,7 @@ static gboolean vala_interface_real_is_subtype_of (ValaTypesymbol* base, ValaTyp
 		prerequisite_it = gee_iterable_iterator (GEE_ITERABLE (prerequisite_collection));
 		while (gee_iterator_next (prerequisite_it)) {
 			ValaDataType* prerequisite;
-			prerequisite = gee_iterator_get (prerequisite_it);
+			prerequisite = ((ValaDataType*) gee_iterator_get (prerequisite_it));
 			{
 				if (vala_data_type_get_data_type (prerequisite) != NULL && vala_typesymbol_is_subtype_of (vala_data_type_get_data_type (prerequisite), t)) {
 					gboolean _tmp1;
@@ -571,7 +695,7 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 		char* _tmp0;
 		_tmp0 = NULL;
 		vala_interface_set_type_cname (self, (_tmp0 = vala_attribute_get_string (a, "type_cname")));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -589,12 +713,12 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 				filename = (_tmp1 = *filename_it, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 				{
 					vala_typesymbol_add_cheader_filename (VALA_TYPESYMBOL (self), filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
-		(val = (g_free (val), NULL));
+		val = (g_free (val), NULL);
 	}
 }
 
@@ -623,12 +747,12 @@ void vala_interface_process_attributes (ValaInterface* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_interface_process_ccode_attribute (self, a);
 				} else {
-					if (g_utf8_collate (vala_attribute_get_name (a), "DBusInterface") == 0) {
+					if (_vala_strcmp0 (vala_attribute_get_name (a), "DBusInterface") == 0) {
 						vala_interface_process_dbus_interface_attribute (self, a);
 					}
 				}
@@ -653,7 +777,7 @@ char* vala_interface_get_type_cname (ValaInterface* self) {
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		self->priv->type_cname = (_tmp1 = g_strdup_printf ("%sIface", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self), FALSE))), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), _tmp1);
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp2 = NULL;
 	return (_tmp2 = self->priv->type_cname, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
@@ -722,9 +846,9 @@ static gint vala_interface_real_get_type_parameter_index (ValaTypesymbol* base,
 		parameter_it = gee_iterable_iterator (GEE_ITERABLE (parameter_collection));
 		while (gee_iterator_next (parameter_it)) {
 			ValaTypeParameter* parameter;
-			parameter = gee_iterator_get (parameter_it);
+			parameter = ((ValaTypeParameter*) gee_iterator_get (parameter_it));
 			{
-				if (g_utf8_collate (vala_symbol_get_name (VALA_SYMBOL (parameter)), name) == 0) {
+				if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (parameter)), name) == 0) {
 					gint _tmp0;
 					return (_tmp0 = i, (parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL))), (parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL))), _tmp0);
 				}
@@ -750,7 +874,7 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = gee_list_get (((GeeList*) self->priv->prerequisites), i)) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+			if ((_tmp1 = (_tmp0 = ((ValaDataType*) gee_list_get (((GeeList*) self->priv->prerequisites), i))) == old_type, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) self->priv->prerequisites), i, new_type);
 				return;
 			}
@@ -853,6 +977,10 @@ static void vala_interface_init (ValaInterface * self) {
 	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->properties = GEE_LIST (gee_array_list_new (VALA_TYPE_PROPERTY, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->signals = GEE_LIST (gee_array_list_new (VALA_TYPE_SIGNAL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->classes = GEE_LIST (gee_array_list_new (VALA_TYPE_CLASS, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->structs = GEE_LIST (gee_array_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->enums = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->delegates = GEE_LIST (gee_array_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
@@ -865,10 +993,14 @@ static void vala_interface_dispose (GObject * obj) {
 	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
 	(self->priv->properties == NULL ? NULL : (self->priv->properties = (g_object_unref (self->priv->properties), NULL)));
 	(self->priv->signals == NULL ? NULL : (self->priv->signals = (g_object_unref (self->priv->signals), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
-	(self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL));
-	(self->priv->type_cname = (g_free (self->priv->type_cname), NULL));
-	(self->priv->type_id = (g_free (self->priv->type_id), NULL));
+	(self->priv->classes == NULL ? NULL : (self->priv->classes = (g_object_unref (self->priv->classes), NULL)));
+	(self->priv->structs == NULL ? NULL : (self->priv->structs = (g_object_unref (self->priv->structs), NULL)));
+	(self->priv->enums == NULL ? NULL : (self->priv->enums = (g_object_unref (self->priv->enums), NULL)));
+	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (g_object_unref (self->priv->delegates), NULL)));
+	self->priv->cname = (g_free (self->priv->cname), NULL);
+	self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL);
+	self->priv->type_cname = (g_free (self->priv->type_cname), NULL);
+	self->priv->type_id = (g_free (self->priv->type_id), NULL);
 	G_OBJECT_CLASS (vala_interface_parent_class)->dispose (obj);
 }
 
@@ -900,5 +1032,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
