@@ -1,6 +1,6 @@
 /* valainterfacewriter.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALAINTERFACEWRITER_H__
@@ -36,9 +36,11 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valaerrorcode.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
-#include <vala/valacallback.h>
+#include <vala/valadelegate.h>
 #include <vala/valamethod.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valaproperty.h>
@@ -62,11 +64,11 @@ typedef struct _ValaInterfaceWriterPrivate ValaInterfaceWriterPrivate;
  * Code visitor generating Vala API file for the public interface.
  */
 struct _ValaInterfaceWriter {
-	ValaCodeVisitor parent;
+	ValaCodeVisitor parent_instance;
 	ValaInterfaceWriterPrivate * priv;
 };
 struct _ValaInterfaceWriterClass {
-	ValaCodeVisitorClass parent;
+	ValaCodeVisitorClass parent_class;
 };
 
 void vala_interface_writer_write_file (ValaInterfaceWriter* self, ValaCodeContext* context, const char* filename);
