@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valalockstatement.h>
@@ -51,8 +51,14 @@ ValaLockStatement* vala_lock_statement_new (ValaExpression* resource, ValaBlock*
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "resource", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, resource), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_BLOCK), g_value_set_object (&__params_it->value, body), __params_it++);
+	__params_it->name = "resource";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, resource);
+	__params_it++;
+	__params_it->name = "body";
+	g_value_init (&__params_it->value, VALA_TYPE_BLOCK);
+	g_value_set_object (&__params_it->value, body);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_LOCK_STATEMENT, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
