@@ -27,6 +27,7 @@
 #include <vala/valainterface.h>
 #include <vala/valastruct.h>
 #include <vala/valaenum.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
@@ -44,6 +45,7 @@ struct _ValaNamespacePrivate {
 	GeeList* interfaces;
 	GeeList* structs;
 	GeeList* enums;
+	GeeList* error_domains;
 	GeeList* delegates;
 	GeeList* constants;
 	GeeList* fields;
@@ -67,6 +69,7 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 static gpointer vala_namespace_parent_class = NULL;
 static void vala_namespace_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 /**
@@ -163,6 +166,19 @@ void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en) {
 }
 
 
+/**
+ * Adds the specified error domain to this namespace.
+ *
+ * @param edomain an error domain
+ */
+void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edomain) {
+	g_return_if_fail (VALA_IS_NAMESPACE (self));
+	g_return_if_fail (edomain == NULL || VALA_IS_ERROR_DOMAIN (edomain));
+	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), edomain);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (edomain)), VALA_SYMBOL (edomain));
+}
+
+
 /**
  * Adds the specified delegate to this namespace.
  *
@@ -277,7 +293,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
 		while (gee_iterator_next (ns_it)) {
 			ValaNamespace* ns;
-			ns = gee_iterator_get (ns_it);
+			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ns), visitor);
 				(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
@@ -292,7 +308,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		en_it = gee_iterable_iterator (GEE_ITERABLE (en_collection));
 		while (gee_iterator_next (en_it)) {
 			ValaEnum* en;
-			en = gee_iterator_get (en_it);
+			en = ((ValaEnum*) gee_iterator_get (en_it));
 			{
 				/* process enums first to avoid order problems in C code */
 				vala_code_node_accept (VALA_CODE_NODE (en), visitor);
@@ -301,6 +317,21 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		}
 		(en_it == NULL ? NULL : (en_it = (g_object_unref (en_it), NULL)));
 	}
+	{
+		GeeList* edomain_collection;
+		GeeIterator* edomain_it;
+		edomain_collection = self->priv->error_domains;
+		edomain_it = gee_iterable_iterator (GEE_ITERABLE (edomain_collection));
+		while (gee_iterator_next (edomain_it)) {
+			ValaErrorDomain* edomain;
+			edomain = ((ValaErrorDomain*) gee_iterator_get (edomain_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (edomain), visitor);
+				(edomain == NULL ? NULL : (edomain = (g_object_unref (edomain), NULL)));
+			}
+		}
+		(edomain_it == NULL ? NULL : (edomain_it = (g_object_unref (edomain_it), NULL)));
+	}
 	{
 		GeeList* cl_collection;
 		GeeIterator* cl_it;
@@ -308,7 +339,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		cl_it = gee_iterable_iterator (GEE_ITERABLE (cl_collection));
 		while (gee_iterator_next (cl_it)) {
 			ValaClass* cl;
-			cl = gee_iterator_get (cl_it);
+			cl = ((ValaClass*) gee_iterator_get (cl_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (cl), visitor);
 				(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
@@ -323,7 +354,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		iface_it = gee_iterable_iterator (GEE_ITERABLE (iface_collection));
 		while (gee_iterator_next (iface_it)) {
 			ValaInterface* iface;
-			iface = gee_iterator_get (iface_it);
+			iface = ((ValaInterface*) gee_iterator_get (iface_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (iface), visitor);
 				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
@@ -338,7 +369,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
 		while (gee_iterator_next (st_it)) {
 			ValaStruct* st;
-			st = gee_iterator_get (st_it);
+			st = ((ValaStruct*) gee_iterator_get (st_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
 				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
@@ -353,7 +384,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		d_it = gee_iterable_iterator (GEE_ITERABLE (d_collection));
 		while (gee_iterator_next (d_it)) {
 			ValaDelegate* d;
-			d = gee_iterator_get (d_it);
+			d = ((ValaDelegate*) gee_iterator_get (d_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (d), visitor);
 				(d == NULL ? NULL : (d = (g_object_unref (d), NULL)));
@@ -368,7 +399,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		c_it = gee_iterable_iterator (GEE_ITERABLE (c_collection));
 		while (gee_iterator_next (c_it)) {
 			ValaConstant* c;
-			c = gee_iterator_get (c_it);
+			c = ((ValaConstant*) gee_iterator_get (c_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
 				(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
@@ -383,7 +414,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
 		while (gee_iterator_next (f_it)) {
 			ValaField* f;
-			f = gee_iterator_get (f_it);
+			f = ((ValaField*) gee_iterator_get (f_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
 				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
@@ -398,7 +429,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
 		while (gee_iterator_next (m_it)) {
 			ValaMethod* m;
-			m = gee_iterator_get (m_it);
+			m = ((ValaMethod*) gee_iterator_get (m_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
@@ -413,7 +444,7 @@ static char* vala_namespace_real_get_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
 	self = VALA_NAMESPACE (base);
 	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cprefixes)) > 0) {
-		return gee_list_get (((GeeList*) self->priv->cprefixes), 0);
+		return ((char*) gee_list_get (((GeeList*) self->priv->cprefixes), 0));
 	} else {
 		if (NULL != vala_symbol_get_name (VALA_SYMBOL (self))) {
 			const char* _tmp1;
@@ -471,7 +502,7 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
-			(_tmp1 = (g_free (_tmp1), NULL));
+			_tmp1 = (g_free (_tmp1), NULL);
 		}
 	}
 	_tmp3 = NULL;
@@ -522,7 +553,7 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 		cheader_filename_it = gee_iterable_iterator (GEE_ITERABLE (cheader_filename_collection));
 		while (gee_iterator_next (cheader_filename_it)) {
 			char* cheader_filename;
-			cheader_filename = gee_iterator_get (cheader_filename_it);
+			cheader_filename = ((char*) gee_iterator_get (cheader_filename_it));
 			{
 				if (first) {
 					first = FALSE;
@@ -530,7 +561,7 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 					g_string_append_c (s, ',');
 				}
 				g_string_append (s, cheader_filename);
-				(cheader_filename = (g_free (cheader_filename), NULL));
+				cheader_filename = (g_free (cheader_filename), NULL);
 			}
 		}
 		(cheader_filename_collection == NULL ? NULL : (cheader_filename_collection = (g_object_unref (cheader_filename_collection), NULL)));
@@ -578,17 +609,17 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 				name = (_tmp2 = *name_it, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 				{
 					vala_namespace_add_cprefix (self, name);
-					(name = (g_free (name), NULL));
+					name = (g_free (name), NULL);
 				}
 			}
-			(name_collection = (_vala_array_free (name_collection, name_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			name_collection = (_vala_array_free (name_collection, name_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
 	}
 	if (vala_attribute_has_argument (a, "lower_case_cprefix")) {
 		char* _tmp3;
 		_tmp3 = NULL;
 		vala_namespace_set_lower_case_cprefix (self, (_tmp3 = vala_attribute_get_string (a, "lower_case_cprefix")));
-		(_tmp3 = (g_free (_tmp3), NULL));
+		_tmp3 = (g_free (_tmp3), NULL);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -606,12 +637,12 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 				filename = (_tmp4 = *filename_it, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 				{
 					gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
-		(val = (g_free (val), NULL));
+		val = (g_free (val), NULL);
 	}
 }
 
@@ -629,9 +660,9 @@ void vala_namespace_process_attributes (ValaNamespace* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_namespace_process_ccode_attribute (self, a);
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -702,6 +733,7 @@ static void vala_namespace_init (ValaNamespace * self) {
 	self->priv->interfaces = GEE_LIST (gee_array_list_new (VALA_TYPE_INTERFACE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->structs = GEE_LIST (gee_array_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->enums = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->error_domains = GEE_LIST (gee_array_list_new (VALA_TYPE_ERROR_DOMAIN, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->delegates = GEE_LIST (gee_array_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->constants = GEE_LIST (gee_array_list_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
@@ -719,12 +751,13 @@ static void vala_namespace_dispose (GObject * obj) {
 	(self->priv->interfaces == NULL ? NULL : (self->priv->interfaces = (g_object_unref (self->priv->interfaces), NULL)));
 	(self->priv->structs == NULL ? NULL : (self->priv->structs = (g_object_unref (self->priv->structs), NULL)));
 	(self->priv->enums == NULL ? NULL : (self->priv->enums = (g_object_unref (self->priv->enums), NULL)));
+	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
 	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (g_object_unref (self->priv->delegates), NULL)));
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
 	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
 	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
 	(self->priv->cprefixes == NULL ? NULL : (self->priv->cprefixes = (g_object_unref (self->priv->cprefixes), NULL)));
-	(self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL));
+	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
 	(self->priv->namespaces == NULL ? NULL : (self->priv->namespaces = (g_object_unref (self->priv->namespaces), NULL)));
 	G_OBJECT_CLASS (vala_namespace_parent_class)->dispose (obj);
@@ -758,5 +791,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
