@@ -1,6 +1,6 @@
 /* valapropertyaccessor.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,7 @@
 #include <vala/valapropertyaccessor.h>
 #include <vala/valaproperty.h>
 #include <vala/valablock.h>
+#include <vala/valabasicblock.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
@@ -32,7 +33,10 @@ struct _ValaPropertyAccessorPrivate {
 	gboolean _readable;
 	gboolean _writable;
 	gboolean _construction;
+	ValaSymbolAccessibility _access;
 	ValaBlock* _body;
+	ValaBasicBlock* _entry_block;
+	ValaBasicBlock* _exit_block;
 	ValaFormalParameter* _value_parameter;
 };
 #define VALA_PROPERTY_ACCESSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY_ACCESSOR, ValaPropertyAccessorPrivate))
@@ -42,7 +46,10 @@ enum  {
 	VALA_PROPERTY_ACCESSOR_READABLE,
 	VALA_PROPERTY_ACCESSOR_WRITABLE,
 	VALA_PROPERTY_ACCESSOR_CONSTRUCTION,
+	VALA_PROPERTY_ACCESSOR_ACCESS,
 	VALA_PROPERTY_ACCESSOR_BODY,
+	VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK,
+	VALA_PROPERTY_ACCESSOR_EXIT_BLOCK,
 	VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER
 };
 static void vala_property_accessor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -141,6 +148,18 @@ void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboole
 }
 
 
+ValaSymbolAccessibility vala_property_accessor_get_access (ValaPropertyAccessor* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), 0);
+	return self->priv->_access;
+}
+
+
+void vala_property_accessor_set_access (ValaPropertyAccessor* self, ValaSymbolAccessibility value) {
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	self->priv->_access = value;
+}
+
+
 ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_body;
@@ -157,6 +176,38 @@ void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* val
 }
 
 
+ValaBasicBlock* vala_property_accessor_get_entry_block (ValaPropertyAccessor* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	return self->priv->_entry_block;
+}
+
+
+void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBasicBlock* value) {
+	ValaBasicBlock* _tmp2;
+	ValaBasicBlock* _tmp1;
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_entry_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL))), _tmp2);
+}
+
+
+ValaBasicBlock* vala_property_accessor_get_exit_block (ValaPropertyAccessor* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
+	return self->priv->_exit_block;
+}
+
+
+void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasicBlock* value) {
+	ValaBasicBlock* _tmp2;
+	ValaBasicBlock* _tmp1;
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_exit_block = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL))), _tmp2);
+}
+
+
 ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY_ACCESSOR (self), NULL);
 	return self->priv->_value_parameter;
@@ -189,9 +240,18 @@ static void vala_property_accessor_get_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_CONSTRUCTION:
 		g_value_set_boolean (value, vala_property_accessor_get_construction (self));
 		break;
+		case VALA_PROPERTY_ACCESSOR_ACCESS:
+		g_value_set_int (value, vala_property_accessor_get_access (self));
+		break;
 		case VALA_PROPERTY_ACCESSOR_BODY:
 		g_value_set_object (value, vala_property_accessor_get_body (self));
 		break;
+		case VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK:
+		g_value_set_object (value, vala_property_accessor_get_entry_block (self));
+		break;
+		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
+		g_value_set_object (value, vala_property_accessor_get_exit_block (self));
+		break;
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		g_value_set_object (value, vala_property_accessor_get_value_parameter (self));
 		break;
@@ -218,9 +278,18 @@ static void vala_property_accessor_set_property (GObject * object, guint propert
 		case VALA_PROPERTY_ACCESSOR_CONSTRUCTION:
 		vala_property_accessor_set_construction (self, g_value_get_boolean (value));
 		break;
+		case VALA_PROPERTY_ACCESSOR_ACCESS:
+		vala_property_accessor_set_access (self, g_value_get_int (value));
+		break;
 		case VALA_PROPERTY_ACCESSOR_BODY:
 		vala_property_accessor_set_body (self, g_value_get_object (value));
 		break;
+		case VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK:
+		vala_property_accessor_set_entry_block (self, g_value_get_object (value));
+		break;
+		case VALA_PROPERTY_ACCESSOR_EXIT_BLOCK:
+		vala_property_accessor_set_exit_block (self, g_value_get_object (value));
+		break;
 		case VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER:
 		vala_property_accessor_set_value_parameter (self, g_value_get_object (value));
 		break;
@@ -243,7 +312,10 @@ static void vala_property_accessor_class_init (ValaPropertyAccessorClass * klass
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_READABLE, g_param_spec_boolean ("readable", "readable", "readable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_WRITABLE, g_param_spec_boolean ("writable", "writable", "writable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_CONSTRUCTION, g_param_spec_boolean ("construction", "construction", "construction", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ACCESS, g_param_spec_int ("access", "access", "access", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_EXIT_BLOCK, g_param_spec_object ("exit-block", "exit-block", "exit-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_ACCESSOR_VALUE_PARAMETER, g_param_spec_object ("value-parameter", "value-parameter", "value-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -257,6 +329,8 @@ static void vala_property_accessor_dispose (GObject * obj) {
 	ValaPropertyAccessor * self;
 	self = VALA_PROPERTY_ACCESSOR (obj);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
+	(self->priv->_entry_block == NULL ? NULL : (self->priv->_entry_block = (g_object_unref (self->priv->_entry_block), NULL)));
+	(self->priv->_exit_block == NULL ? NULL : (self->priv->_exit_block = (g_object_unref (self->priv->_exit_block), NULL)));
 	(self->priv->_value_parameter == NULL ? NULL : (self->priv->_value_parameter = (g_object_unref (self->priv->_value_parameter), NULL)));
 	G_OBJECT_CLASS (vala_property_accessor_parent_class)->dispose (obj);
 }
