@@ -1,6 +1,6 @@
 /* valapropertyaccessor.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valacodenode.h>
+#include <vala/valasymbol.h>
 
 G_BEGIN_DECLS
 
@@ -43,11 +44,11 @@ typedef struct _ValaPropertyAccessorPrivate ValaPropertyAccessorPrivate;
  * Represents a get or set accessor of a property in the source code.
  */
 struct _ValaPropertyAccessor {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaPropertyAccessorPrivate * priv;
 };
 struct _ValaPropertyAccessorClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaPropertyAccessor* vala_property_accessor_new (gboolean readable, gboolean writable, gboolean construction, ValaBlock* body, ValaSourceReference* source_reference);
@@ -59,8 +60,14 @@ gboolean vala_property_accessor_get_writable (ValaPropertyAccessor* self);
 void vala_property_accessor_set_writable (ValaPropertyAccessor* self, gboolean value);
 gboolean vala_property_accessor_get_construction (ValaPropertyAccessor* self);
 void vala_property_accessor_set_construction (ValaPropertyAccessor* self, gboolean value);
+ValaSymbolAccessibility vala_property_accessor_get_access (ValaPropertyAccessor* self);
+void vala_property_accessor_set_access (ValaPropertyAccessor* self, ValaSymbolAccessibility value);
 ValaBlock* vala_property_accessor_get_body (ValaPropertyAccessor* self);
 void vala_property_accessor_set_body (ValaPropertyAccessor* self, ValaBlock* value);
+ValaBasicBlock* vala_property_accessor_get_entry_block (ValaPropertyAccessor* self);
+void vala_property_accessor_set_entry_block (ValaPropertyAccessor* self, ValaBasicBlock* value);
+ValaBasicBlock* vala_property_accessor_get_exit_block (ValaPropertyAccessor* self);
+void vala_property_accessor_set_exit_block (ValaPropertyAccessor* self, ValaBasicBlock* value);
 ValaFormalParameter* vala_property_accessor_get_value_parameter (ValaPropertyAccessor* self);
 void vala_property_accessor_set_value_parameter (ValaPropertyAccessor* self, ValaFormalParameter* value);
 GType vala_property_accessor_get_type (void);
