@@ -58,7 +58,7 @@ void vala_report_warning (ValaSourceReference* source, const char* message) {
 		char* _tmp0;
 		_tmp0 = NULL;
 		fprintf (stderr, "%s: warning: %s\n", (_tmp0 = vala_source_reference_to_string (source)), message);
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 }
 
@@ -78,7 +78,7 @@ void vala_report_error (ValaSourceReference* source, const char* message) {
 		char* _tmp0;
 		_tmp0 = NULL;
 		fprintf (stderr, "%s: error: %s\n", (_tmp0 = vala_source_reference_to_string (source)), message);
-		(_tmp0 = (g_free (_tmp0), NULL));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 }
 
