@@ -44,11 +44,11 @@ typedef struct _ValaReturnStatementPrivate ValaReturnStatementPrivate;
  * Represents a return statement in the source code.
  */
 struct _ValaReturnStatement {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaReturnStatementPrivate * priv;
 };
 struct _ValaReturnStatementClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference);
