@@ -82,8 +82,8 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 				_tmp4 = NULL;
 				_tmp3 = NULL;
 				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (vala_scope_get_owner (self))), (_tmp4 = g_strdup_printf ("`%s' already contains a definition for `%s'", (_tmp3 = vala_symbol_get_full_name (vala_scope_get_owner (self))), name)));
-				(_tmp4 = (g_free (_tmp4), NULL));
-				(_tmp3 = (g_free (_tmp3), NULL));
+				_tmp4 = (g_free (_tmp4), NULL);
+				_tmp3 = (g_free (_tmp3), NULL);
 				return;
 			}
 		}
@@ -106,7 +106,7 @@ ValaSymbol* vala_scope_lookup (ValaScope* self, const char* name) {
 	if (self->priv->symbol_table == NULL) {
 		return NULL;
 	}
-	sym = gee_map_get (((GeeMap*) self->priv->symbol_table), name);
+	sym = ((ValaSymbol*) gee_map_get (((GeeMap*) self->priv->symbol_table), name));
 	if (sym != NULL && !vala_symbol_get_active (sym)) {
 		ValaSymbol* _tmp1;
 		_tmp1 = NULL;
