@@ -1,6 +1,6 @@
 /* valatypecheck.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,12 +31,12 @@
 G_BEGIN_DECLS
 
 
-#define VALA_TYPE_TYPE_CHECK (vala_type_check_get_type ())
-#define VALA_TYPE_CHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPE_CHECK, ValaTypeCheck))
-#define VALA_TYPE_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPE_CHECK, ValaTypeCheckClass))
-#define VALA_IS_TYPE_CHECK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPE_CHECK))
-#define VALA_IS_TYPE_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPE_CHECK))
-#define VALA_TYPE_CHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPE_CHECK, ValaTypeCheckClass))
+#define VALA_TYPE_TYPECHECK (vala_typecheck_get_type ())
+#define VALA_TYPECHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPECHECK, ValaTypeCheck))
+#define VALA_TYPECHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPECHECK, ValaTypeCheckClass))
+#define VALA_IS_TYPECHECK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPECHECK))
+#define VALA_IS_TYPECHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPECHECK))
+#define VALA_TYPECHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPECHECK, ValaTypeCheckClass))
 
 typedef struct _ValaTypeCheckPrivate ValaTypeCheckPrivate;
 
@@ -44,19 +44,19 @@ typedef struct _ValaTypeCheckPrivate ValaTypeCheckPrivate;
  * Represents a type check (`is') expression in the source code.
  */
 struct _ValaTypeCheck {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaTypeCheckPrivate * priv;
 };
 struct _ValaTypeCheckClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
-ValaTypeCheck* vala_type_check_new (ValaExpression* expr, ValaTypeReference* type, ValaSourceReference* source);
-ValaExpression* vala_type_check_get_expression (ValaTypeCheck* self);
-void vala_type_check_set_expression (ValaTypeCheck* self, ValaExpression* value);
-ValaTypeReference* vala_type_check_get_type_reference (ValaTypeCheck* self);
-void vala_type_check_set_type_reference (ValaTypeCheck* self, ValaTypeReference* value);
-GType vala_type_check_get_type (void);
+ValaTypeCheck* vala_typecheck_new (ValaExpression* expr, ValaDataType* type, ValaSourceReference* source);
+ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self);
+void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value);
+ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self);
+void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value);
+GType vala_typecheck_get_type (void);
 
 G_END_DECLS
 
