@@ -78,7 +78,7 @@ ValaArray* vala_typeparameter_get_array (ValaTypeParameter* self, gint rank) {
 	if (self->priv->array_types != NULL) {
 		ValaArray* _tmp0;
 		_tmp0 = NULL;
-		array_type = (_tmp0 = gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank)), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp0);
+		array_type = (_tmp0 = ((ValaArray*) gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), _tmp0);
 	}
 	if (array_type == NULL) {
 		ValaArray* new_array_type;
